# Tailer: A tool for 3' end analysis of non-polyadenylated RNAs from 3' sequencing data

## Requirements
- ``Python >= 3.6``
- ``pysam``
- ``Bio``
- ``gffuitls``

## Installation

```bash
pip install jla-tailer
```

## Usage
```bash
Tailer -a \[GTF Annotation\] \[SAM or BAM Files\]
```
